[![PyPI badge](http://img.shields.io/pypi/v/scippnexus.svg)](https://pypi.python.org/pypi/scippnexus)
[![Anaconda-Server Badge](https://anaconda.org/scipp/scippnexus/badges/installer/conda.svg)](https://anaconda.org/scipp/scippnexus)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)

# ScippNeXus

## About

scippnexus is a h5py-like utility for NeXus files based with seamless scipp integration.
See the [documentation](https://scipp.github.io/scippnexus) for more details.

## Installation

```sh
python -m pip install scippnexus
```

## Contributing Organizations

The following organizations have made major contributions to the development of scippnexus:

* [European Spallation Source ERIC](https://europeanspallationsource.se/), Sweden

See individual [release notes](https://scipp.github.io/scippnexus/about/release-notes.html) for the individual contributors to each release.
